/******************************************************************************
 * Copyright 2021 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import type { CallHierarchyIncomingCallsParams, CallHierarchyOutgoingCallsParams, CancellationToken, Connection, Disposable, Event, HandlerResult, InitializedParams, InitializeParams, InitializeResult, RequestHandler, ServerRequestHandler, TextDocumentIdentifier } from 'vscode-languageserver';
import type { LangiumServices, LangiumSharedServices } from '../services.js';
import type { LangiumDocument } from '../workspace/documents.js';
import { Emitter } from 'vscode-languageserver';
export interface LanguageServer {
    initialize(params: InitializeParams): Promise<InitializeResult>;
    initialized(params: InitializedParams): Promise<void>;
    onInitialize(callback: (params: InitializeParams) => void): Disposable;
    onInitialized(callback: (params: InitializedParams) => void): Disposable;
}
export declare class DefaultLanguageServer implements LanguageServer {
    protected onInitializeEmitter: Emitter<InitializeParams>;
    protected onInitializedEmitter: Emitter<InitializedParams>;
    protected readonly services: LangiumSharedServices;
    constructor(services: LangiumSharedServices);
    get onInitialize(): Event<InitializeParams>;
    get onInitialized(): Event<InitializedParams>;
    initialize(params: InitializeParams): Promise<InitializeResult>;
    /**
     * Eagerly loads all services before emitting the `onInitialize` event.
     * Ensures that all services are able to catch the event.
     */
    protected eagerLoadServices(): void;
    protected hasService(callback: (language: LangiumServices) => object | undefined): boolean;
    protected buildInitializeResult(_params: InitializeParams): InitializeResult;
    initialized(params: InitializedParams): Promise<void>;
}
export declare function startLanguageServer(services: LangiumSharedServices): void;
export declare function addDocumentsHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addDiagnosticsHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addCompletionHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addFindReferencesHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addCodeActionHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addDocumentSymbolHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addGotoDefinitionHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addGoToTypeDefinitionHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addGoToImplementationHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addGoToDeclarationHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addDocumentHighlightsHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addHoverHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addFoldingRangeHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addFormattingHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addRenameHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addInlayHintHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addSemanticTokenHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addConfigurationChangeHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addExecuteCommandHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addDocumentLinkHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addSignatureHelpHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addCodeLensHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addWorkspaceSymbolHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function addCallHierarchyHandler(connection: Connection, services: LangiumSharedServices): void;
export declare function createCallHierarchyRequestHandler<P extends CallHierarchyIncomingCallsParams | CallHierarchyOutgoingCallsParams, R, PR, E = void>(serviceCall: (services: LangiumServices, params: P, cancelToken: CancellationToken) => HandlerResult<R, E>, sharedServices: LangiumSharedServices): ServerRequestHandler<P, R, PR, E>;
export declare function createServerRequestHandler<P extends {
    textDocument: TextDocumentIdentifier;
}, R, PR, E = void>(serviceCall: (services: LangiumServices, document: LangiumDocument, params: P, cancelToken: CancellationToken) => HandlerResult<R, E>, sharedServices: LangiumSharedServices): ServerRequestHandler<P, R, PR, E>;
export declare function createRequestHandler<P extends {
    textDocument: TextDocumentIdentifier;
}, R, E = void>(serviceCall: (services: LangiumServices, document: LangiumDocument, params: P, cancelToken: CancellationToken) => HandlerResult<R, E>, sharedServices: LangiumSharedServices): RequestHandler<P, R | null, E>;
//# sourceMappingURL=language-server.d.ts.map