/******************************************************************************
 * Copyright 2022 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import type { Connection, DidChangeConfigurationParams } from 'vscode-languageserver';
import type { ServiceRegistry } from '../service-registry.js';
import type { LangiumSharedServices } from '../services.js';
export interface ConfigurationProvider {
    /**
    * Returns a configuration value stored for the given language.
    *
    * @param language The language id
    * @param configuration Configuration name
    */
    getConfiguration(language: string, configuration: string): Promise<any>;
    /**
     *  Updates the cached configurations using the `change` notification parameters.
     *
     * @param change The parameters of a change configuration notification.
     * `settings` property of the change object could be expressed as `Record<string, Record<string, any>>`
     */
    updateConfiguration(change: DidChangeConfigurationParams): void;
}
export declare class DefaultConfigurationProvider implements ConfigurationProvider {
    protected settings: Record<string, Record<string, any>>;
    protected workspaceConfig: boolean;
    protected initialized: boolean;
    protected readonly serviceRegistry: ServiceRegistry;
    protected readonly connection: Connection | undefined;
    constructor(services: LangiumSharedServices);
    protected initialize(): Promise<void>;
    updateConfiguration(change: DidChangeConfigurationParams): void;
    protected updateSectionConfiguration(section: string, configuration: any): void;
    getConfiguration(language: string, configuration: string): Promise<any>;
    protected toSectionName(languageId: string): string;
}
//# sourceMappingURL=configuration.d.ts.map